==> estateplat-common-1.2.4-20210517.070858-752-sources.jar: cn/gtmap/estateplat/model/exchange/national/KtfZhYhydzb.java <==
package cn.gtmap.estateplat.model.exchange.national;

import cn.gtmap.estateplat.utils.JaxbDoubleAdapter;
import cn.gtmap.estateplat.utils.JaxbDoubleEightAdapter;
import cn.gtmap.estateplat.utils.JaxbIntegerAdapter;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import java.io.Serializable;
import java.util.Date;

/**
 * 用海、用岛坐标
 * Created by xhc on 2015/11/19.
 */
@XmlRootElement(name = "KTF_ZH_YHYDZB")
public class KtfZhYhydzb implements Serializable, AccessData {
    private String zhhddm;//宗海/海盗代码
    private Integer xh;//序号
    private Double bw;//北纬
    private Double dj;//东经
    private String qxdm;//区县代码
    /**  插入更新时间
     * @author <a href="mailto:zhangqiang@gtmap.cn">zhangqiang</a>
     * @description
     */
    private Date updatetime;
    /**  插入创建时间
     * @author <a href="mailto:zhangqiang@gtmap.cn">zhangqiang</a>
     * @description
     */
    private Date createtime;
    @XmlTransient
    public Date getCreatetime() {
        return createtime;
    }

    public void setCreatetime(Date createtime) {
        this.createtime = createtime;
    }
    @XmlTransient
    public Date getUpdatetime() {
        return updatetime;
    }

    public void setUpdatetime(Date updatetime) {
        this.updatetime = updatetime;
    }
    @XmlAttribute(name = "ZHHDDM")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getZhhddm() {
        return zhhddm;
    }

    public void setZhhddm(String zhhddm) {
        this.zhhddm = zhhddm;
    }

    @XmlAttribute(name = "XH")
    public Integer getXh() {
        return xh;
    }

    public void setXh(Integer xh) {
        this.xh = xh;
    }

    @XmlAttribute(name = "BW")
    @XmlJavaTypeAdapter(JaxbDoubleEightAdapter.class)
    public Double getBw() {
        return bw;
    }

    public void setBw(Double bw) {
        this.bw = bw;
    }

    @XmlAttribute(name = "DJ")
    @XmlJavaTypeAdapter(JaxbDoubleEightAdapter.class)
    public Double getDj() {
        return dj;
    }

    public void setDj(Double dj) {
        this.dj = dj;
    }

    @XmlAttribute(name = "QXDM")
    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }
}

==> estateplat-common-1.2.4-20210914.065054-871-sources.jar: cn/gtmap/estateplat/model/exchange/national/KtfZhYhydzb.java <==
package cn.gtmap.estateplat.model.exchange.national;

import cn.gtmap.estateplat.utils.JaxbDoubleAdapter;
import cn.gtmap.estateplat.utils.JaxbDoubleEightAdapter;
import cn.gtmap.estateplat.utils.JaxbIntegerAdapter;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import java.io.Serializable;
import java.util.Date;

/**
 * 用海、用岛坐标
 * Created by xhc on 2015/11/19.
 */
@XmlRootElement(name = "KTF_ZH_YHYDZB")
public class KtfZhYhydzb implements Serializable, AccessData {
    private String zhhddm;//宗海/海盗代码
    private Integer xh;//序号
    private Double bw;//北纬
    private Double dj;//东经
    private String qxdm;//区县代码
    /**  插入更新时间
     * @author <a href="mailto:zhangqiang@gtmap.cn">zhangqiang</a>
     * @description
     */
    private Date updatetime;
    /**  插入创建时间
     * @author <a href="mailto:zhangqiang@gtmap.cn">zhangqiang</a>
     * @description
     */
    private Date createtime;

    private String zhdm;//宗海代码
    private String msb;//面标识
    @XmlAttribute(name = "ZHDM")
    public String getZhdm() {
        return zhdm;
    }

    public void setZhdm(String zhdm) {
        this.zhdm = zhdm;
    }
    @XmlAttribute(name = "MSB")
    public String getMsb() {
        return msb;
    }

    public void setMsb(String msb) {
        this.msb = msb;
    }

    @XmlTransient
    public Date getCreatetime() {
        return createtime;
    }

    public void setCreatetime(Date createtime) {
        this.createtime = createtime;
    }
    @XmlTransient
    public Date getUpdatetime() {
        return updatetime;
    }

    public void setUpdatetime(Date updatetime) {
        this.updatetime = updatetime;
    }
    @XmlAttribute(name = "ZHHDDM")
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getZhhddm() {
        return zhhddm;
    }

    public void setZhhddm(String zhhddm) {
        this.zhhddm = zhhddm;
    }

    @XmlAttribute(name = "XH")
    public Integer getXh() {
        return xh;
    }

    public void setXh(Integer xh) {
        this.xh = xh;
    }

    @XmlAttribute(name = "BW")
    @XmlJavaTypeAdapter(JaxbDoubleEightAdapter.class)
    public Double getBw() {
        return bw;
    }

    public void setBw(Double bw) {
        this.bw = bw;
    }

    @XmlAttribute(name = "DJ")
    @XmlJavaTypeAdapter(JaxbDoubleEightAdapter.class)
    public Double getDj() {
        return dj;
    }

    public void setDj(Double dj) {
        this.dj = dj;
    }

    @XmlAttribute(name = "QXDM")
    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }
}
